# CLI documentation

Below is the automatically generated docummentation for `box`.
You can also find this by typing `box --help` in your terminal.



::: mkdocs-click
    :module: box.cli
    :command: cli
    :prog_name: box
    :depth: 1
    :style: table
